aboutsummaryrefslogtreecommitdiffstats
path: root/src/main/scala/org/perl8/test/tap/TAPEvent.scala
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/scala/org/perl8/test/tap/TAPEvent.scala')
-rw-r--r--src/main/scala/org/perl8/test/tap/TAPEvent.scala21
1 files changed, 11 insertions, 10 deletions
diff --git a/src/main/scala/org/perl8/test/tap/TAPEvent.scala b/src/main/scala/org/perl8/test/tap/TAPEvent.scala
index 0f9318b..1c2e88d 100644
--- a/src/main/scala/org/perl8/test/tap/TAPEvent.scala
+++ b/src/main/scala/org/perl8/test/tap/TAPEvent.scala
@@ -1,6 +1,6 @@
-package org.perl8.test.tap
+package com.iinteractive.test.tap
-import org.perl8.test.Plan
+import com.iinteractive.test.Plan
/** An event emitted while parsing a TAP stream. */
sealed trait TAPEvent
@@ -9,23 +9,24 @@ sealed trait TAPEvent
case object StartEvent extends TAPEvent
/** The end of a TAP stream.
* @param result The [[org.perl8.test.tap.TAPResult TAPResult]] containing
* information about all of the tests which just finished
* running. This will be the same thing that is returned by the
* call to [[org.perl8.test.tap.Parser Parser]]'s `parse`
* method.
*/
case class EndEvent private[tap] (result: TAPResult) extends TAPEvent
/** An individual test result.
* @param result The [[org.perl8.test.tap.TestResult TestResult]] containing
* information about the corresponding test.
*/
case class ResultEvent private[tap] (result: TestResult) extends TAPEvent
/** A test plan.
* @param plan The [[org.perl8.test.Plan Plan]] corresponding to the line that
* was parsed.
*/
case class PlanEvent private[tap] (plan: Plan) extends TAPEvent
@@ -9,23 +9,24 @@ sealed trait TAPEvent
case object StartEvent extends TAPEvent
/** The end of a TAP stream.
- * @param result The [[org.perl8.test.tap.TAPResult TAPResult]] containing
- * information about all of the tests which just finished
- * running. This will be the same thing that is returned by the
- * call to [[org.perl8.test.tap.Parser Parser]]'s `parse`
+ * @param result The [[com.iinteractive.test.tap.TAPResult TAPResult]]
+ * containing information about all of the tests which just
+ * finished running. This will be the same thing that is
+ * returned by the call to
+ * [[com.iinteractive.test.tap.Parser Parser]]'s `parse`
* method.
*/
@@ -9,23 +9,24 @@ sealed trait TAPEvent
case class EndEvent private[tap] (result: TAPResult) extends TAPEvent
/** An individual test result.
- * @param result The [[org.perl8.test.tap.TestResult TestResult]] containing
- * information about the corresponding test.
+ * @param result The [[com.iinteractive.test.tap.TestResult TestResult]]
+ * containing information about the corresponding test.
*/
case class ResultEvent private[tap] (result: TestResult) extends TAPEvent
@@ -9,23 +9,24 @@ sealed trait TAPEvent
case class ResultEvent private[tap] (result: TestResult) extends TAPEvent
/** A test plan.
- * @param plan The [[org.perl8.test.Plan Plan]] corresponding to the line that
- * was parsed.
+ * @param plan The [[com.iinteractive.test.Plan Plan]] corresponding to the
+ * line that was parsed.
*/
case class PlanEvent private[tap] (plan: Plan) extends TAPEvent